#
# spec file for package perl-Email-Simple
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Email-Simple
Name:           perl-Email-Simple
Version:        2.218
Release:        bp160.1.7
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Simple parsing of RFC2822 message format and headers
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/R/RJ/RJBS/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Email::Date::Format)
BuildRequires:  perl(ExtUtils::MakeMaker) >= 6.78
BuildRequires:  perl(Test::More) >= 0.96
Requires:       perl(Email::Date::Format)
%{perl_requires}

%description
The Email:: namespace was begun as a reaction against the increasing
complexity and bugginess of Perl's existing email modules. 'Email::*'
modules are meant to be simple to use and to maintain, pared to the bone,
fast, minimal in their external dependencies, and correct.

%prep
%autosetup  -n %{cpan_name}-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes README
%license LICENSE

%changelog
* Mon Jan  9 2023 Tina Müller <timueller+perl@suse.de>
- updated to 2.218
  see /usr/share/doc/packages/perl-Email-Simple/Changes
  2.218     2023-01-08 19:49:09-05:00 America/New_York
  - update author contact info
  - bump version required to v5.12.0 (it was already effectively that
    after some upstream changes)
  2.217     2020-11-02 19:13:16-05:00 America/New_York (TRIAL RELEASE)
  - add ->header_rename to header object
  - issue a warning on non-ASCII codepoints added to message (thanks,
    Pali Rohár)
* Thu Jun  7 2018 coolo@suse.com
- updated to 2.216
  see /usr/share/doc/packages/perl-Email-Simple/Changes
  2.216     2018-06-06 11:47:52-04:00 America/New_York
  - no changes since v2.215
  2.215     2018-05-04 16:21:28+10:00 Australia/Melbourne (TRIAL RELEASE)
  - do not re-fold folded lines (Marc Bradshaw)
* Sat Sep  9 2017 coolo@suse.com
- updated to 2.214
  see /usr/share/doc/packages/perl-Email-Simple/Changes
  2.214     2017-09-08 14:21:20-04:00 America/New_York
  - the method header_raw_prepend is now available on emails and headers
* Mon Feb 13 2017 coolo@suse.com
- updated to 2.213
  see /usr/share/doc/packages/perl-Email-Simple/Changes
  2.213     2017-01-11 09:21:54-05:00 America/New_York
  - no changes since v2.212
  2.212     2016-12-18 20:05:09-05:00 America/New_York (TRIAL RELEASE)
  - add an $index arg to ->header to get the nth header (thanks, Pali
    Rohár)
* Sun Nov 13 2016 coolo@suse.com
- updated to 2.211
  see /usr/share/doc/packages/perl-Email-Simple/Changes
  2.211     2016-11-12 09:39:09-05:00 America/New_York
  - fix a fencepost error in headers and header_names that led to a
    spurious undef in return and to a warning (thanks, Pali Rohár)
* Tue Mar  8 2016 coolo@suse.com
- updated to 2.210
  see /usr/share/doc/packages/perl-Email-Simple/Changes
  2.210     2016-03-05 12:16:16-05:00 America/New_York
  - fix a bug where folding treated the string "0" as an empty string
    (thanks, Pali Rohár)
  2.209     2015-10-11 22:57:04-04:00 America/New_York (TRIAL RELEASE)
  - avoid opportunity for pathological backtracking behavior on
    malformed messages
* Tue Jul 21 2015 coolo@suse.com
- updated to 2.208
  see /usr/share/doc/packages/perl-Email-Simple/Changes
  2.208     2015-07-20 20:34:04-04:00 America/New_York
  - same as v2.207
  - ...but bump perl required to v5.8
  2.207     2015-07-04 14:23:36-04:00 America/New_York (TRIAL RELEASE)
  - fold headers passed to header arg in create method
    https://github.com/rjbs/Email-Simple/issues/7
* Tue Apr 14 2015 coolo@suse.com
- updated to 2.206
  see /usr/share/doc/packages/perl-Email-Simple/Changes
  2.206     2015-03-26 23:30:51-04:00 America/New_York
  - the changes from 2.204 are back (and re-listed here), but now with
    the added benefit of not breaking Email::MIME; see the git repository
    for the sordid details
  - provide header_raw and header_raw_set for consistent behavior between
    Email::Simple and Email::MIME; also, header_raw_pairs
  2.205     2015-03-26 14:54:45-04:00 America/New_York
  - undo changes from 2.204 until safe Email::MIME upgrade path is
    available
  2.204     2015-03-25 22:50:49-04:00 America/New_York
  - provide header_raw and header_raw_set for consistent behavior between
    Email::Simple and Email::MIME; also, header_raw_pairs
* Mon Feb 24 2014 coolo@suse.com
- updated to 2.203
  - translate vertical whitespace in headers into horizontal whitespace,
    with a warning
* Fri Oct  4 2013 coolo@suse.com
- updated to 2.202
  repackage with Dist::Zilla; update repo and bug tracker
* Tue Jun  4 2013 coolo@suse.com
- updated to 2.201
    preserve the original header layout unless changed
    fix a bug in header unfolding where "0\n 1" could be unfolded to "01"
    recognize crlf correctly even if there is no body (thanks, Christian
    Walde)
* Sat Dec 24 2011 pascal.bleser@opensuse.org
- update to 2.101:
  * remove instruction to use ::Creator instead of just ->create
  * documentation improvements
* Fri Dec  2 2011 coolo@suse.com
- use original tar
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Wed Nov 24 2010 chris@computersalat.de
- recreated by cpanspec 1.78
- noarch pkg
- changelog to changes file
- fix changelog
* Fri Sep 14 2007 coolo@novell.com
- update to 2.100
  - merge Email-Simple-Creator into Email-Simple distribution
- 2.005     2009-01-22
  - add repository metadata
- 2.004     2008-06-25
  - publicize default_header_class method
  - remove the long-deprecated Headers.pm
* Fri Sep 14 2007 jfunk@funktronics.ca
- Initial release 2.003
